@@ -524,10 +524,10 @@ module Parser
 
       label = value(key_t)
       value =
-        if label =~ /\A[[:lower:]]/
-          n(:ident, [ label.to_sym ], Source::Map::Variable.new(value_l))
-        else
+        if label =~ /\A[[:upper:]]/
           n(:const, [ nil, label.to_sym ], Source::Map::Constant.new(nil, value_l, value_l))
+        else
+          n(:ident, [ label.to_sym ], Source::Map::Variable.new(value_l))
         end
       pair_keyword(key_t, accessible(value))
     end
@@ -1120,15 +1120,19 @@ module Parser
     end
 
     def block(method_call, begin_t, args, body, end_t)
-      _receiver, _selector, *call_args = *method_call
-
       if method_call.type == :yield
         diagnostic :error, :block_given_to_yield, nil, method_call.loc.keyword, [loc(begin_t)]
       end
 
-      last_arg = call_args.last
+      if method_call.type == :super
+        *_args, last_arg = *method_call
+      else
+        _receiver, _selector, *_args, last_arg = *method_call
+      end
       if last_arg && (last_arg.type == :block_pass || last_arg.type == :forwarded_args)
-        diagnostic :error, :block_and_blockarg, nil, last_arg.loc.expression, [loc(begin_t)]
+        if (@parser.version == 33 && method_call.type != :super) || @parser.version != 33
+          diagnostic :error, :block_and_blockarg, nil, last_arg.loc.expression, [loc(begin_t)]
+        end
       end
 
       if args.type == :numargs
@@ -1192,6 +1196,10 @@ module Parser
     end
 
     def index_asgn(receiver, lbrack_t, indexes, rbrack_t)
+      if self.class.emit_kwargs
+        rewrite_hash_args_to_kwargs(indexes)
+      end
+
       if self.class.emit_index
         n(:indexasgn, [ receiver, *indexes ],
           index_map(receiver, lbrack_t, rbrack_t))
@@ -2263,7 +2271,12 @@ module Parser
         source
       end
 
-      Regexp.new(source, (Regexp::EXTENDED if options.children.include?(:x)))
+      begin
+        old_verbose, $VERBOSE = $VERBOSE, nil
+        Regexp.new(source, (Regexp::EXTENDED if options.children.include?(:x)))
+      ensure
+        $VERBOSE = old_verbose
+      end
     end
 
     def static_regexp_node(node)
